@@ -223,7 +223,7 @@ def get_drives():
             ]
         )
         for line in r.split("\n"):
-            words = re.split("\s+", line)
+            words = re.split("\\s+", line)
             if len(words) >= 3 and words[1] == "2" and words[2] == "FAT":
                 drives.append(words[0])
     else:
