@@ -15,19 +15,6 @@
 #include "snek.h"
 #include "snek-io.h"
 
-#ifndef SNEK_IO_PUTS
-#define SNEK_IO_PUTS(s)	fputs(s, stdout)
-#endif
-#ifndef SNEK_IO_PUTC
-#define SNEK_IO_PUTC(c) putchar(c)
-#endif
-#ifndef SNEK_IO_WAITING
-#define SNEK_IO_WAITING(s) false
-#endif
-#ifndef SNEK_IO_LINEBUF
-#define SNEK_IO_LINEBUF	132
-#endif
-
 static bool	raw_mode;
 static char	buf[SNEK_IO_LINEBUF];
 static uint8_t	used, avail;
@@ -36,8 +23,7 @@ static void
 snek_io_backspace(void)
 {
 	avail--;
-	if (!raw_mode)
-		SNEK_IO_PUTS("\b \b");
+	SNEK_IO_PUTS("\b \b");
 }
 
 static void
@@ -62,19 +48,15 @@ snek_io_getc(FILE *stream)
 		if (!snek_in_input)
 #endif
 		{
-	restart_cooked:
 			if (snek_parse_middle)
 				SNEK_IO_PUTC('+');
 			else
 				SNEK_IO_PUTC('>');
 			SNEK_IO_PUTC(' ');
 		}
-	restart_raw:
 		used = avail = 0;
 		for (;;) {
-			if (!SNEK_IO_WAITING(stream))
-				fflush(stdout);
-			uint8_t c;
+			char c;
 
 #ifdef SNEK_BUILTIN_input
 			if (unget) {
@@ -82,11 +64,10 @@ snek_io_getc(FILE *stream)
 				unget = 0;
 			} else
 #endif
-			c = SNEK_IO_GETC(stream);
+			c = snek_raw_getc(stream);
 
 			switch (c)
 			{
-			case '\r':
 			case '\n':
 				snek_io_addc('\n');
 				break;
@@ -103,11 +84,9 @@ snek_io_getc(FILE *stream)
 					return EOF;
 				}
 #endif
-				snek_abort = false;
-				if (raw_mode)
-					goto restart_raw;
-				SNEK_IO_PUTS("^C\n");
-				goto restart_cooked;
+				if (!raw_mode)
+					SNEK_IO_PUTS("^C\n");
+				return EOF;
 			case 'h' & 0x1f:
 			case 0x7f:
 				if (avail)
@@ -121,7 +100,7 @@ snek_io_getc(FILE *stream)
 				c = ' ';
 				/* fall through ... */
 			default:
-				if (c >= (uint8_t)' ') {
+				if ((uint8_t) c >= (uint8_t)' ') {
 					if (avail < SNEK_IO_LINEBUF-1)
 						snek_io_addc(c);
 				}
